@@ -66,6 +66,8 @@ const (
 	kernelTypesVar = "kernelTypes"
 
 	AnnotationFlushOnStop = "ebpf.map.flush-on-stop"
+	AnnotationRestName    = "ebpf.rest.name"
+	AnnotationRestLen     = "ebpf.rest.len"
 )
 
 type gadgetObjects struct {
@@ -452,6 +454,19 @@ func (i *ebpfInstance) register(gadgetCtx operators.GadgetContext) error {
 			return fmt.Errorf("adding datasource: %w", err)
 		}
 		m.accessor = accessor
+		// handle trailing data if configured
+		if restName, ok := ds.Annotations()[AnnotationRestName]; ok {
+			m.restAccessor, err = ds.AddField(restName, api.Kind_Bytes)
+			if err != nil {
+				return fmt.Errorf("adding rest accessor: %w", err)
+			}
+			if restLenName, ok := ds.Annotations()[AnnotationRestLen]; ok {
+				m.restLenAccessor = ds.GetField(restLenName)
+				if m.restLenAccessor == nil {
+					return fmt.Errorf("rest length accessor field %q not found", restLenName)
+				}
+			}
+		}
 		m.ds = ds
 	}
 	for name, m := range i.snapshotters {
@@ -871,7 +886,7 @@ func (i *ebpfInstance) AttachContainer(container *containercollection.Container)
 	i.mu.Unlock()
 
 	for _, networkTracer := range i.networkTracers {
-		if err := networkTracer.Attach(container.ContainerPid()); err != nil {
+		if err := networkTracer.AttachContainer(container); err != nil {
 			return err
 		}
 	}
@@ -899,7 +914,7 @@ func (i *ebpfInstance) DetachContainer(container *containercollection.Container)
 	i.mu.Unlock()
 
 	for _, networkTracer := range i.networkTracers {
-		if err := networkTracer.Detach(container.ContainerPid()); err != nil {
+		if err := networkTracer.DetachContainer(container); err != nil {
 			return err
 		}
 	}
